@@ -6,6 +6,7 @@ COMMANDS
     cluster
     verify
     verify_single
+    verify_ref
     release_match
 
   Run, e.g. fuzzycat cluster --help for more options.
@@ -38,6 +39,10 @@ EXAMPLES
         ]
       }
 
+  Verify clustered refs:
+
+      $ python -m fuzzycat verify-ref
+
   Release match (non-bulk).
 
       $ python -m fuzzycat release_match -q "hello world"
@@ -66,6 +71,7 @@ from fuzzycat.cluster import (Cluster, release_key_title, release_key_title_ngra
                               release_key_title_sandcrawler)
 from fuzzycat.entities import entity_to_dict
 from fuzzycat.matching import anything_to_entity, match_release_fuzzy
+from fuzzycat.refs import RefsGroupVerifier
 from fuzzycat.utils import random_idents_from_query, random_word
 from fuzzycat.verify import GroupVerifier, verify
 
@@ -92,6 +98,7 @@ def run_cluster(args):
     cluster = Cluster(iterable=fileinput.input(args.files),
                       key=types.get(args.type),
                       tmpdir=args.tmpdir,
+                      compress=args.compress,
                       key_denylist=key_denylist,
                       prefix=args.prefix)
     cluster.run()
@@ -160,6 +167,11 @@ def run_verify_single(args):
     print(json.dumps(result))
 
 
+def run_ref_verify(args):
+    verifier = RefsGroupVerifier(iterable=fileinput.input(files=args.files), verbose=args.verbose)
+    verifier.run()
+
+
 def run_release_match(args):
     """
     Given a release, return similar releases.
@@ -217,6 +229,10 @@ if __name__ == '__main__':
 
     sub_cluster = subparsers.add_parser('cluster', help='group entities', parents=[parser])
     sub_cluster.set_defaults(func=run_cluster)
+    sub_cluster.add_argument('-C',
+                             '--compress',
+                             action="store_true",
+                             help='compress intermediate results')
     sub_cluster.add_argument('-f', '--files', default="-", help='input files')
     sub_cluster.add_argument('--key-denylist', help='file path to key denylist')
     sub_cluster.add_argument('--min-cluster-size',
@@ -243,6 +259,10 @@ if __name__ == '__main__':
     sub_verify_single.add_argument('-b', help='ident or url to release')
     sub_verify_single.set_defaults(func=run_verify_single)
 
+    sub_ref_verify = subparsers.add_parser('verify_ref', help='verify ref groups', parents=[parser])
+    sub_ref_verify.add_argument('-f', '--files', default="-", help='input files')
+    sub_ref_verify.set_defaults(func=run_ref_verify)
+
     sub_release_match = subparsers.add_parser(
         "release_match",
         help="find release matches",
